@@ -20,7 +20,7 @@
 #include "k9dvdauthor.h"
 #include "k9dvdtitle.h"
 #include "k9dvdbackup.h"
-#include "kmessagebox.h"
+
 #include "k9tools.h"
 
 #include <sys/types.h>
@@ -35,12 +35,17 @@
 #include <qfile.h>
 #include <qlabel.h>
 #include <qprogressdialog.h>
-#include <signal.h>
+#include <kdialog.h>
+#ifdef BACKLITE
+#include <QMessageBox>
+#else
+#include "kmessagebox.h"
 #include <klocale.h>
-#include <kstandarddirs.h>
+#include <KShell>
+#endif
 #include <qapplication.h>
 #include <QTextStream>
-#include <KShell>
+
 
 class k9Progress;
 
@@ -55,7 +60,7 @@ k9DVDAuthor::k9DVDAuthor(QObject *DVDStruct)  {
 }
 k9DVDAuthor::~k9DVDAuthor() {
 
-    foreach (KTemporaryFile *it,files) {
+    foreach (QTemporaryFile *it,files) {
         it->remove();
     }
     while (!files.isEmpty()) delete files.takeFirst();
@@ -79,24 +84,19 @@ void k9DVDAuthor::createXML() {
     root.appendChild(vmgm);
     addMenus(vmgm);
 
-    m_totalPartSize=0;
 
     m_forced=0;
     m_forcedsh=0;
-    uint64_t chapterssize=0;
     //computes the size of related titles
     for (int iTitle=0; iTitle < DVD->gettitleCount();iTitle++) {
         k9DVDTitle *title=DVD->gettitle(iTitle);
         if (title->isSelected() && title->getIndexed()) {
-            chapterssize+= title->getChaptersSize(false);
             for (int iTitle2=0;iTitle2<title->getTitles().count() ;iTitle2++) {
                 k9DVDTitle *title2=title->getTitles().at(iTitle2);
-                m_totalPartSize+= title2->getsize_mb() *1024*1024;
                 if (title->getforceFactor()) {
                     m_forced+=title2->getsectors()*2048;
                     m_forcedsh+=(title2->getsectors()/title->getfactor())*2048;
                 }
-                chapterssize+= title2->getChaptersSize(false);
             }
         }
         //total size of forced titles
@@ -108,8 +108,7 @@ void k9DVDAuthor::createXML() {
     }
 
     //total size of titles to copy
-    m_totalSize=((uint64_t)DVD->getsizeSelected(false))*DVD_VIDEO_LB_LEN + m_totalPartSize -chapterssize*DVD_VIDEO_LB_LEN;
-
+    m_totalSize=((uint64_t)DVD->getsizeSelected(false))*DVD_VIDEO_LB_LEN ;//+ m_totalPartSize -chapterssize*DVD_VIDEO_LB_LEN;
     m_firsttitle=true;
 
     for (i=0;i< DVD->gettitleCount();i++) {
@@ -144,8 +143,8 @@ void k9DVDAuthor::addMenus(QDomElement &titleSet) {
             error=true;
             QString sMsg;
             //sMsg.QString::sprintf(tr2i18n("'%s' not selected"),l_track->getname().latin1());
-            sMsg=i18n("'%1' not selected",l_track->getname());
-            k9Dialogs::error( sMsg, tr2i18n("authoring"));
+            sMsg=i18n("'%1' not selected").arg(l_track->getname());
+            k9Dialogs::error( sMsg, i18n("authoring"));
         }
         start.sprintf("jump titleset %d menu;",DVD->getnewTitleNum(l_track));
     }
@@ -231,13 +230,10 @@ void k9DVDAuthor::addTitle(QDomElement &root, k9DVDTitle *title) {
         pre.appendChild(precmd);
 
         //create palette for subpictures
-        KTemporaryFile *paletteFile=new KTemporaryFile();
-
-        paletteFile->setPrefix(KStandardDirs::locateLocal("tmp", "k9copy/k9p"));
-        paletteFile->setSuffix(".yuv");
+        QTemporaryFile *paletteFile=new QTemporaryFile(m_tempPath+"/k9pXXXXXX.yuv");
+        paletteFile->setAutoRemove(false);
         paletteFile->open();
         files.append(paletteFile);
-        paletteFile->setAutoRemove(false);
         palette=paletteFile->fileName();
 
         //palette.sprintf("palette%d.yuv",l_track->getnumTitle());
@@ -348,7 +344,13 @@ void k9DVDAuthor::addTitle(QDomElement &root, k9DVDTitle *title) {
                     uint32_t itotSize = (cell->getlastSector()-cell->getstartSector())* DVD_VIDEO_LB_LEN;
                     QString file;
                     e=xml->createElement("vob");
-                    file=QString(qApp->applicationDirPath()+ "/k9play --play --input %1 --dvdtitle %2 %3 %4  %5  %6 --vampsfactor %7 --inputsize %8 --chaptersize %9 ")
+                    QString playPgm="";
+#ifdef BACKLITE
+                    playPgm="/backlite";
+#else
+                    playPgm="/k9play";
+#endif
+                    file=QString(qApp->applicationDirPath()+ playPgm+" --play --input %1 --dvdtitle %2 %3 %4  %5  %6 --vampsfactor %7 --inputsize %8 --chaptersize %9 ")
                          .arg(KShell::quoteArg(DVD->getDevice()))
                          .arg(title->getnumTitle())
                          .arg(sChapter)
@@ -389,8 +391,8 @@ void k9DVDAuthor::addTitle(QDomElement &root, k9DVDTitle *title) {
             c.sprintf("g1=%d;\ncall vmgm menu;",DVD->getnewTitleNum(l_next));
             if ( DVD->getnewTitleNum(l_next)==-1) {
                 error=true;
-                c=i18n("'%1' not selected",l_next->getname());
-                k9Dialogs::error( c, tr2i18n("authoring"));
+                c=i18n("'%1' not selected").arg(l_next->getname());
+                k9Dialogs::error( c, i18n("authoring"));
             }
 
             postcmd.setNodeValue(c);
@@ -413,7 +415,7 @@ void k9DVDAuthor::setworkDir( const QString& _newVal) {
 void k9DVDAuthor::author() {
     k9Config config;
     if ( ! k9Tools::checkProgram("dvdauthor")) {
-        k9Dialogs::error (i18n("Unable to run %1","dvdauthor") , i18n("authoring"));
+        k9Dialogs::error (i18n("Unable to run %1").arg("dvdauthor") , i18n("authoring"));
         error = TRUE;
         return;
     }
@@ -426,20 +428,20 @@ void k9DVDAuthor::author() {
     time = new QTime(0,0);
     time->start();
 
+    m_tempPath=config.getPrefOutput();
+    QDir dir;
+    dir.mkpath(workDir+DVD->getDVDTitle());
+    dir.mkpath(m_tempPath);
     progress->setTitle(i18n("Authoring"));
     progress->setWindowTitle(KDialog::makeStandardCaption(i18n("Backup progression")));
     progress->setProgress(0,100);
     //progress->show();
 
-    m_xml=new KTemporaryFile();
-    m_xml->setPrefix(KStandardDirs::locateLocal("tmp", "k9copy/k9a"));
-    m_xml->setSuffix(".xml");
+    m_xml=new QTemporaryFile(m_tempPath+"/k9aXXXXXX.xml");
     m_xml->open();
     QString fileName=m_xml->fileName();
 
-    m_inject=new KTemporaryFile();
-    m_inject->setPrefix(KStandardDirs::locateLocal("tmp", "k9copy/k9v"));
-    m_inject->setSuffix(".inj");
+    m_inject=new QTemporaryFile(m_tempPath+"/k9vXXXXXX.inj");
     m_inject->open();
     inject=m_inject->fileName();
 
@@ -454,10 +456,10 @@ void k9DVDAuthor::author() {
         proc=progress->getProcess();//  new QProcess(c,0);
 
         *proc << c << "-x" <<  fileName;  //locateLocal("tmp", "k9copy/k9author.xml");
-        connect( proc, SIGNAL(receivedStderr(KProcess *, char *, int)),
-                 this, SLOT(DVDAuthorStderr(KProcess *, char *, int )) );
-        connect( proc, SIGNAL(receivedStdout(KProcess *, char *, int )),
-                 this, SLOT(DVDAuthorStdout(KProcess *, char *, int)) );
+        connect( proc, SIGNAL(receivedStderr(char *, int)),
+                 this, SLOT(DVDAuthorStderr(char *, int )) );
+        connect( proc, SIGNAL(receivedStdout(char *, int )),
+                 this, SLOT(DVDAuthorStdout(char *, int)) );
         //    connect(progress, SIGNAL(cancelled()), this, SLOT(stopProcess()));
 
         m_copied=0;
@@ -467,7 +469,7 @@ void k9DVDAuthor::author() {
         proc-> setWorkingDirectory(workDir);
         int result=progress->execute();
         if ( result==-1 ) {
-            k9Dialogs::error(tr2i18n("Dvdauthor error :\n") + lastMsg,tr2i18n("authoring"));
+            k9Dialogs::error(i18n("Dvdauthor error :\n") + lastMsg,i18n("authoring"));
 
         } else {
             cancelled=(result==0);
@@ -476,17 +478,17 @@ void k9DVDAuthor::author() {
             } else {
                 if (cancelled) {
                     //QMessageBox::critical( 0, tr2i18n("authoring"), tr2i18n("Authoring canceled"));
-                    k9Dialogs::error( tr2i18n("Authoring cancelled"),tr2i18n("authoring"));
-
+                    k9Dialogs::error( i18n("Authoring cancelled"),i18n("authoring"));                  
                 } else
-                    k9Dialogs::error( tr2i18n("An error occured while running DVDAuthor:\n")+lastMsg ,tr2i18n("authoring"));
+                    k9Dialogs::error( i18n("An error occured while running DVDAuthor:\n")+lastMsg ,i18n("authoring"));
 
             }
         }
         //        delete proc;
 //       delete progress;
-        if (!burnOk)
+        if (!burnOk) {
             error=true;
+        }
     }
 
     delete time;
@@ -498,7 +500,7 @@ void k9DVDAuthor::author() {
 
 
 /** No descriptions */
-void k9DVDAuthor::DVDAuthorStderr(KProcess *, char *buffer, int buflen ) {
+void k9DVDAuthor::DVDAuthorStderr(char *buffer, int buflen ) {
 
     //QString m_stderr(proc->readStderr());
     QString m_stderr=QString::fromLatin1(buffer, buflen);
@@ -567,7 +569,7 @@ void k9DVDAuthor::DVDAuthorStderr(KProcess *, char *buffer, int buflen ) {
 
 }
 
-void k9DVDAuthor::DVDAuthorStdout(KProcess *, char *buffer, int buflen) {
+void k9DVDAuthor::DVDAuthorStdout(char *buffer, int buflen) {
     QString c=QString::fromLatin1( buffer,buflen);
     //(proc->readStdout());
     int pos;
