@@ -13,8 +13,22 @@
 #define K9EXECCOPY
 #include "k9dvd.h"
 #include <QObject>
+#ifdef BACKLITE
+#include <QProgressDialog>
+class KProgressDialog:public QProgressDialog {
+public:
+    KProgressDialog (QWidget *parent):QProgressDialog(parent) {}
+    QProgressDialog * progressBar() { return this;}
+    void showCancelButton(bool _visible) {
+        if (_visible)
+           setCancelButtonText(i18n("Cancel"));
+        else
+           setCancelButtonText("");
+    }
+};
+#else
 #include <KProgressDialog>
-
+#endif
 class k9ResultingFile;
 class k9ExecCopy:public QObject  {
 Q_OBJECT
@@ -42,14 +56,14 @@ public:
         m_path = theValue;
     }
 
-	void setSpeed(const QString& theValue);
+    void setSpeed(const QString& theValue);
 	
-
-
-
-
+    bool isCancelled() {
+        return m_cancelled;
+    }
 private:
     k9DVD *m_dvd;
+    bool m_cancelled;
     QString m_speed;
     QString m_path;
     eOutput m_output;
@@ -59,7 +73,7 @@ private:
     QStringList m_outputMsg;
     int m_mkvPos;
 protected slots:
-    void MkvStdout(KProcess *, char *, int );
+    void MkvStdout(char *, int );
     void finished(int, QProcess::ExitStatus);
 };
 
