@@ -126,6 +126,7 @@ void k9Config::read() {
     defCol << true << true <<true << true;
     m_prefColumns=group.readEntry<bool>("columns",defCol);
 
+    m_prefShowOutput=group.readEntry("showOutput",true);
 }
 
 void k9Config::save() {
@@ -206,6 +207,7 @@ void k9Config::save() {
 
     group=m_config->group("gui");
     group.writeEntry("columns",m_prefColumns);
+    group.writeEntry("showOutput",m_prefShowOutput);
 
 }
 
