@@ -24,10 +24,7 @@
 #include "k9cellcopylist.h"
 #include "k9dvdprogress.h"
 #include "k9ifo2.h"
-#include <qapplication.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include "k9tools.h"
+#include <QApplication>
 #include <sys/stat.h>
 
 
@@ -93,6 +90,9 @@ int k9DVD::getmenuSize() {
 k9DVD::k9DVD(QObject  *parent) :QObject(parent)  {
     m_error=false;
     m_opened=false;
+    m_arrLng=new lng[200];
+    k9DVD::LangList(m_arrLng);
+
 //   m_titles.setAutoDelete(true);
 //   m_titlesets.setAutoDelete(true);
     m_lvideoFormat.append("NTSC");
@@ -173,6 +173,7 @@ k9DVD::~k9DVD() {
         m_dvd.close();
     deleteTitles();
     deleteTitlesets();
+    delete[] m_arrLng;
 }
 
 void k9DVD::deleteTitles() {
@@ -208,7 +209,7 @@ int k9DVD::get_title_name(const char* dvd_device, char* title) {
     int  i;
     QString c;
     if (! (filehandle = fopen(dvd_device, "r"))) {
-        c=i18n("Couldn't open %1 for title\n",dvd_device);
+        c=i18n("Couldn't open %1 for title\n").arg(dvd_device);
         // setError(c );
         strcpy(title, i18n("unknown").toUtf8());
         return -1;
@@ -216,7 +217,7 @@ int k9DVD::get_title_name(const char* dvd_device, char* title) {
 
     if ( fseek(filehandle, 32808, SEEK_SET )) {
         fclose(filehandle);
-        c=i18n("Couldn't seek in %1 for title\n",dvd_device);
+        c=i18n("Couldn't seek in %1 for title\n").arg(dvd_device);
         setError(c);
         strcpy(title, i18n("unknown").toUtf8());
         return -1;
@@ -239,11 +240,8 @@ int k9DVD::get_title_name(const char* dvd_device, char* title) {
     return 0;
 }
 
-lng m_arrLng[200];
-bool initLng=false;
 
-lng* k9DVD::LangList() {
-    if (!initLng) {
+void k9DVD::LangList(lng *_arrLng) {
         lng arrLng[] = {
             { "  ", i18n("Not Specified") }, { "aa", i18n("Afar") },	{ "ab", i18n("Abkhazian") }, { "af", i18n("Afrikaans") },	{ "am", i18n("Amharic")},
             { "ar", i18n("Arabic") }, { "as", i18n("Assamese") },	{ "ay", i18n("Aymara") }, { "az", i18n("Azerbaijani") }, { "ba", i18n("Bashkir") },
@@ -274,20 +272,16 @@ lng* k9DVD::LangList() {
             { "vo", i18n("Volapuk") }, { "wo", i18n("Wolof") }, { "xh", i18n("Xhosa") }, { "yi", i18n("Yiddish") }, { "yo", i18n("Yoruba") }, { "za", i18n("Zhuang") },
             { "zh", i18n("Chinese") }, { "zu", i18n("Zulu") }, { "xx", i18n("Unknown") }, { "\0", i18n("Unknown") }
         };
-        for (int i=0; i <(sizeof(arrLng)/sizeof(lng));i++) {
-            m_arrLng[i]=arrLng[i];
+        for (uint i=0; i <(sizeof(arrLng)/sizeof(lng));i++) {
+            _arrLng[i]=arrLng[i];
         }
-        initLng=true;
-    }
-    return m_arrLng;
 }
 
 
 QString k9DVD::lang_name(const QString& code,const QString & name) {
     QString c;
     int i=0;
-    lng * arrLng=k9DVD::LangList();
-
+    lng* arrLng=m_arrLng;
     c=i18n("Unknown");
     for (i=0 ; arrLng[i].code[0]!=0;i++) {
         lng l =arrLng[i];
@@ -378,7 +372,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
         m_dvd.close();
     m_dvd.openDevice(device);
     if ( !m_dvd.opened() ) {
-        c=i18n("Can't open disc %1!\n",device);
+        c=i18n("Can't open disc %1!\n").arg(device);
         setError(c);
         return 2;
     }
@@ -432,7 +426,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                 vts_ttn =  ttn;//ifo->vts_ptt_srpt->title[j].ptt[0].pgcn; //ifo_zero->tt_srpt->title[j].vts_ttn;
 
                 //JMPtxt=i18n("Title %1").arg(indexedCount);
-                txt=i18n("Title %1",numTitle);
+                txt=i18n("Title %1").arg(numTitle);
                 emit sigTotalText (txt);
                 emit sigTitleProgress(numTitle,ltitles);
                 video_attr = &vtsi_mat->vts_video_attr;
@@ -722,7 +716,7 @@ k9DVDTitle* k9DVD::addTitle(k9DVDTitleset *_titleset,int id,int num,uint _VTS,in
     }
     if (bappend)
         m_titles.append(track);
-    track->name=i18n("Title %1",num);
+    track->name=i18n("Title %1").arg(num);
 
     if (!_indexed) {
         for (int i=0;i<m_titles.count();i++) {
@@ -892,7 +886,7 @@ long k9DVD::stream_vob( int title, unsigned long startblock, unsigned long lastb
     QString c;
     dvdfile =m_dvd.openTitle( title);
     if ( !dvdfile ) {
-        c=i18n("Error opening vobs for title %1\n",title);
+        c=i18n("Error opening vobs for title %1\n").arg(title);
         setError(c);
         return 0;
     }
@@ -903,7 +897,7 @@ long k9DVD::stream_vob( int title, unsigned long startblock, unsigned long lastb
         emit sigVobProgress(i-startblock,lastblock-startblock);
         total+=size;
         if ( !size ) {
-            c=i18n("ERROR reading block %1\n",i);
+            c=i18n("ERROR reading block %1\n").arg(i);
             setError(c);
             break;
         }
