@@ -22,10 +22,9 @@
 #include "k9common.h"
 #include <QObject>
 #include "k9dvdread.h"
-#include <qstringlist.h>
-#include <qdatetime.h>
+#include <QStringList>
+#include <QDateTime>
 #include <QList>
-//#include <qvaluelist.h>
 
 
 struct streamSize {
@@ -82,10 +81,11 @@ private:
   QString m_format;
   k9DVDTitle* m_start;
   int m_titlesetCount;
+  lng *m_arrLng;
 public: 
   k9DVD(QObject  *parent=0) ;
   ~k9DVD();
-  static lng* LangList();
+  static void  LangList(lng *arrLng);
   /**
    * Opens and estimates the size of each stream
    * @param device input device
@@ -146,7 +146,7 @@ public:
   virtual void close();
   virtual k9DVDTitleset *gettitleset(int num);
   virtual k9DVDRead * getdvd() {return &m_dvd;}
-  static QString lang_name(const QString & code,const QString & name);
+  QString lang_name(const QString & code,const QString & name);
   int dvdtime2msec(dvd_time_t *dt);
 private: // Private methods
   k9DVDRead  m_dvd;
