@@ -15,11 +15,11 @@
 
 #include "k9common.h"
 #include "ui_progress.h"
-#include <k9process.h>
-#include <qimage.h>
-#include <qtimer.h>
+#include <QImage>
+#include <QTimer>
 #include "k9drawimage.h"
-
+#include <QMovie>
+#include <QDialog>
 class k9Progress : public QDialog {
     Q_OBJECT
 
@@ -49,12 +49,17 @@ protected:
     k9Process *m_process;
     k9DrawImage *m_wimage;
     bool m_canceled;
+    void closeEvent ( QCloseEvent * event );
+    void showEvent ( QShowEvent * event );
 protected slots:
     /*$PROTECTED_SLOTS$*/
     void bCancelClick();
+    void gbOutputToggled(bool state);
 
 private:
     Ui::Progress Ui_Progress;
+    int m_outputSize;
+    QMovie *m_movie;
 };
 
 #endif
