@@ -15,27 +15,28 @@
 #include <qfile.h>
 #include <stdio.h>
 #include <qtextstream.h>
-#include <kstandarddirs.h>
 #include <qapplication.h>
-#include <ktemporaryfile.h>
-#include <kapplication.h>
-#include <klocale.h>
 #include <qimage.h>
-#include <kmessagebox.h>
 #include "k9menu.h"
 #include "k9menubutton.h"
 #include "k9processlist.h"
 #include <qthread.h>
 #include <qfileinfo.h>
-#include <KRandom>
 #include "k9cell.h"
 #include "k9ifo2.h"
 #include "nav_types.h"
 #include "ifo_types.h"
 #include "dvdread.h"
+#include <QDir>
+#ifndef BACKLITE
+#include <kstandarddirs.h>
+#include <ktemporaryfile.h>
+#include <kapplication.h>
+#endif
+
 k9NewDVD::k9NewDVD(QObject *parent, const char *)
         : QObject(parent) {
-    m_workDir=KStandardDirs::locateLocal("tmp", "k9copy/" ) ;
+    m_workDir=k9Tools::getTempPath();;
     m_rootMenu=new k9Menu(this);
     m_format=PAL;
 }
@@ -80,10 +81,11 @@ void k9NewDVD::setFormat ( const eFormat& _value ) {
 }
 
 void k9NewDVD::createXML() {
-
+    QDir d;
+    d.mkpath(m_workDir+"/dvd");
     m_rootMenu->setWorkDir(m_workDir);
 
-    QString menuFileName=m_workDir+KRandom::randomString(8)+".mpg";
+    QString menuFileName=m_workDir+k9Tools::randomFileName()+".mpg";
     m_rootMenu->setMenuFileName(menuFileName);
 
     m_xml=new QDomDocument();
@@ -118,7 +120,7 @@ void k9NewDVD::createXML() {
     m_cancel=m_processList->getCancel();
     bool error=false;
     if (!m_cancel) {
-        QString dvdAuthor(m_workDir+"/"+KRandom::randomString(8)+".xml");
+        QString dvdAuthor(m_workDir+"/"+k9Tools::randomFileName()+".xml");
         QFile file( dvdAuthor);
 
         file.open(QIODevice::WriteOnly);
@@ -128,7 +130,7 @@ void k9NewDVD::createXML() {
 
         m_processList->clear();
         k9Process *process=m_processList->addProcess(i18n("authoring"));
-        connect(process, SIGNAL(receivedStderr(KProcess *, char *, int)),this, SLOT(getStderr(KProcess *, char *, int) ));
+        connect(process, SIGNAL(receivedStderr(k9Process *,char *, int)),this, SLOT(getStderr(k9Process *,char *, int) ));
         *process << m_config->getPrefDvdauthorPath(true)  << "-x" << dvdAuthor;
         m_processList->execute();
         m_cancel=m_processList->getCancel();
@@ -162,10 +164,10 @@ void k9NewDVD::addTitles (QDomElement &_root) {
         QDomElement pgc;
         k9Menu *menu=title->getMenu();
         menu->setWorkDir(m_workDir);
-        QString menuFileName=m_workDir+KRandom::randomString(8)+".mpg";
+        QString menuFileName=m_workDir+k9Tools::randomFileName()+".mpg";
         m_tmpFiles << menuFileName,
         menu->setMenuFileName(menuFileName);
-        m_processList->addProgress(i18n("Creating menu for title %1",title->getNum()+1));
+        m_processList->addProgress(i18n("Creating menu for title %1").arg(title->getNum()+1));
         if (!menu->createMenus(&titleSet))
 		return;
 
@@ -253,7 +255,7 @@ void k9NewDVD::createMencoderCmd(QString &_cmd,QString &_chapters, k9AviFile *_a
     //m_progress->setTitle(i18n("Encoding file"));
     //m_process->clearArguments();
     if (_aviFile->getReencode()) {
-        QString fileName= m_workDir + KRandom::randomString(8)+".mpeg";
+        QString fileName= m_workDir + k9Tools::randomFileName()+".mpeg";
         QString t1=_aviFile->getStart().toString("hh:mm:ss.zzz");
         int length=_aviFile->getStart().msecsTo(end);
         QTime l;
@@ -272,13 +274,13 @@ void k9NewDVD::createMencoderCmd(QString &_cmd,QString &_chapters, k9AviFile *_a
             break;
         }
 
-        k9Process *process=m_processList->addProcess(i18n("Encoding %1",_aviFile->getFileName()));
+        k9Process *process=m_processList->addProcess(i18n("Encoding %1").arg(_aviFile->getFileName()));
         m_processList->setFileName(process,_aviFile->getFileName());
 
         QTime t(0,0);
         t.start();
         m_timers[process]=t;
-        connect(process, SIGNAL(receivedStdout(KProcess *, char *, int)),this, SLOT(getStdout(KProcess *, char *, int) ));
+        connect(process, SIGNAL(receivedStdout(k9Process*, char *, int)),this, SLOT(getStdout(k9Process*,char *, int) ));
 
         *process <<  m_config->getPrefMencoderPath(true) << "-oac" << "lavc" << "-ovc" << "lavc" << "-of" << "mpeg" << "-afm" << "libmad";
         *process << "-mpegopts" << "format=dvd" << "-vf" << "scale="+scale+",harddup" << "-srate" << "48000" << "-af" << "lavcresample=48000";
@@ -338,7 +340,7 @@ void k9NewDVD::splitFile(k9AviFile *_aviFile) {
 		output->close();
 		delete output;
 		}
-		QString fileName= m_workDir + KRandom::randomString(8)+".mpeg";
+                QString fileName= m_workDir + k9Tools::randomFileName()+".mpeg";
 		m_splitCells << fileName;
 		output=new QFile(fileName);
 		output->open(QIODevice::WriteOnly);
@@ -367,7 +369,7 @@ int64_t k9NewDVD::readscr(const unsigned char *buf)
         ((buf[4]&0xf8)>>3);
 }
 
-void k9NewDVD::getStderr(KProcess *_process, char *_buffer, int _length) {
+void k9NewDVD::getStderr(k9Process *_process,char *_buffer, int _length) {
     QString tmp=QString::fromAscii(_buffer,_length);
     m_stdout=tmp;
     int pos;
@@ -406,7 +408,7 @@ void k9NewDVD::getStderr(KProcess *_process, char *_buffer, int _length) {
     }
 }
 
-void k9NewDVD::getStdout(KProcess *_process, char *_buffer, int _length) {
+void k9NewDVD::getStdout(k9Process *_process,char *_buffer, int _length) {
     k9Process *process=(k9Process*) _process;
     if (m_timers[process].elapsed() >500) {
         QString tmp=QString::fromAscii(_buffer,_length);
@@ -476,8 +478,8 @@ void k9NewDVD::appendTitle(k9Title *_title) {
     btn->setWidth(m_config->getPrefButtonWidth());
     btn->setHeight(m_config->getPrefButtonHeight());
     btn->setScript(QString("g1=0;jump titleset %1  menu;").arg(_title->getNum()+1));
-    btn->setTextPosition(k9MenuButton::RIGHT);
-    btn->setText(i18n("title %1",_title->getNum()+1));
+    btn->setTextPosition(RIGHT);
+    btn->setText(i18n("title %1").arg(_title->getNum()+1));
     btn->setColor(m_config->getPrefButtonTextColor());
     btn->setFont(m_config->getPrefButtonFont());
 
