@@ -12,9 +12,10 @@
 
 
 #include "k9playbackoptions.h"
-#include "k9config.h"
 #include <kpushbutton.h>
+#ifndef BACKLITE
 #include <kiconloader.h>
+#endif
 
 k9PlaybackOptions::k9PlaybackOptions(k9Main *mainWindow, QWidget* parent)
 : QWidget(parent)
@@ -23,8 +24,6 @@ k9PlaybackOptions::k9PlaybackOptions(k9Main *mainWindow, QWidget* parent)
     setMain( mainWindow);
     m_main->setPlaybackOptions(this);
     enable(false);
-    Ui_playbackOptionsw.bSeqUp->setIcon(SmallIcon("arrow-up"));
-    Ui_playbackOptionsw.bSeqDown->setIcon(SmallIcon("arrow-down"));
     k9Config config;
     Ui_playbackOptionsw.ckMenu->setChecked(config.getKeepMenus());
     ckMenuClick();
@@ -42,7 +41,9 @@ k9PlaybackOptions::~k9PlaybackOptions()
 
 
 void k9PlaybackOptions::fillTitleList() {
-    QString txt=Ui_playbackOptionsw.lbSequence->currentText();
+    QString txt;
+    if (Ui_playbackOptionsw.lbSequence->currentItem() !=NULL)
+        Ui_playbackOptionsw.lbSequence->currentItem()->text();
 
     Ui_playbackOptionsw.lbSequence->clear();
     k9DVDTitle *title=m_dvd->getstart();
@@ -68,7 +69,7 @@ void k9PlaybackOptions::fillTitleList() {
             QString sTitle=l_track->getname();
             if(l_track->isSelected()) {
    		bool foundtitle=false;
-		for (uint j=0; j<Ui_playbackOptionsw.lbSequence->count();j++) {
+                for (int j=0; j<Ui_playbackOptionsw.lbSequence->count();j++) {
 		   lbItem *tmp=(lbItem*)Ui_playbackOptionsw.lbSequence->item(j);
 		   if (tmp->getTitle() == l_track)
 			foundtitle=true;
@@ -82,8 +83,8 @@ void k9PlaybackOptions::fillTitleList() {
             }
         }
     }
-    if (Ui_playbackOptionsw.lbSequence->currentItem()==-1)
-	Ui_playbackOptionsw.lbSequence->setCurrentItem(0);
+    if (Ui_playbackOptionsw.lbSequence->currentRow()==-1)
+        Ui_playbackOptionsw.lbSequence->setCurrentRow(0);
     setSequence();
     enable(!Ui_playbackOptionsw.ckMenu->isChecked() );
 
@@ -98,45 +99,24 @@ void k9PlaybackOptions::ckMenuClick() {
 	enable(false);
 }
 
-void k9PlaybackOptions::bSeqUpClick() {
-    int cur=Ui_playbackOptionsw.lbSequence->currentItem();
-    if (cur >0) {
-        lbItem *lbi=(lbItem*)Ui_playbackOptionsw.lbSequence->item(cur);
-        Ui_playbackOptionsw.lbSequence->takeItem(lbi);
-        Ui_playbackOptionsw.lbSequence->insertItem(lbi,cur-1);
-        Ui_playbackOptionsw.lbSequence->setCurrentItem(lbi);
-    }
-    setSequence();
-}
-
-void k9PlaybackOptions::bSeqDownClick() {
-    uint cur=Ui_playbackOptionsw.lbSequence->currentItem();
-    if (cur <Ui_playbackOptionsw.lbSequence->count()) {
-        lbItem *lbi=(lbItem*)Ui_playbackOptionsw.lbSequence->item(cur);
-        Ui_playbackOptionsw.lbSequence->takeItem(lbi);
-        Ui_playbackOptionsw.lbSequence->insertItem(lbi,cur+1);
-        Ui_playbackOptionsw.lbSequence->setCurrentItem(lbi);
-    }
-    setSequence();
-}
 
 void k9PlaybackOptions::setSequence() {
     for (int i=0;i <m_dvd->gettitleCount();i++)
 	m_dvd->gettitle(i)->setnextTitle( NULL);
 
-    lbItem *lbi = (lbItem*)Ui_playbackOptionsw.lbSequence->item(Ui_playbackOptionsw.lbSequence->topItem());
+    lbItem *lbi = (lbItem*)Ui_playbackOptionsw.lbSequence->item(0);
     if (lbi !=NULL) {
 	lbItem *lbi2;
 	m_dvd->setstart(lbi->getTitle());
-	for (uint i=0 ; i < Ui_playbackOptionsw.lbSequence->count()-1;i++) {
+        for (int i=0 ; i < Ui_playbackOptionsw.lbSequence->count()-1;i++) {
 		lbi=(lbItem*)Ui_playbackOptionsw.lbSequence->item(i);
 		lbi2=(lbItem*)Ui_playbackOptionsw.lbSequence->item(i+1);
 		lbi->getTitle()->setnextTitle(lbi2->getTitle());
-	}
+         }
     }
 }
 
-void k9PlaybackOptions::lbSequenceChanged(Q3ListBoxItem *_item) {
+void k9PlaybackOptions::lbSequenceChanged(QListWidgetItem *_item,QListWidgetItem *) {
     if (_item == NULL)
 	return;
     lbItem *lbi=(lbItem*) _item;
@@ -176,24 +156,22 @@ void k9PlaybackOptions::lbSequenceChanged(Q3ListBoxItem *_item) {
 }
 
 void k9PlaybackOptions::cbDefAudioActivated(int _index) {
-    int cur=Ui_playbackOptionsw.lbSequence->currentItem();
+    int cur=Ui_playbackOptionsw.lbSequence->currentRow();
     lbItem *lbi=(lbItem*)Ui_playbackOptionsw.lbSequence->item(cur);
     lbi->getTitle()->setDefAudio(lstAudioDef.at(_index));
 }
  
 void k9PlaybackOptions::cbDefSubActivated(int _index) {
-    int cur=Ui_playbackOptionsw.lbSequence->currentItem();
+    int cur=Ui_playbackOptionsw.lbSequence->currentRow();
     lbItem *lbi=(lbItem*)Ui_playbackOptionsw.lbSequence->item(cur);
     lbi->getTitle()->setDefSubtitle(lstSubDef.at(_index));
 }
 
 void k9PlaybackOptions::titleRenamed (k9DVDTitle *_title, QString _newName) {
-    for (uint j=0; j<Ui_playbackOptionsw.lbSequence->count();j++) {
+    for (int j=0; j<Ui_playbackOptionsw.lbSequence->count();j++) {
 	    lbItem *tmp=(lbItem*)Ui_playbackOptionsw.lbSequence->item(j);
 	     if (tmp->getTitle() == _title) {
-		lbItem *item=new lbItem(NULL,_newName);
-		item->setTitle(_title);
-		Ui_playbackOptionsw.lbSequence->changeItem(item,j);
+                Ui_playbackOptionsw.lbSequence->item(j)->setText(_newName);
 		break;
 	     }
 	}	
