@@ -12,12 +12,9 @@
 
 
 #include "k9prefdvd.h"
-#include "k9config.h"
-#include <kstandarddirs.h>
 #include <kurlrequester.h>
 #include <qcheckbox.h>
 #include <qspinbox.h>
-#include <klocale.h>
 #include "k9tools.h"
 #include "k9dvd.h"
 k9prefDVD::k9prefDVD(QWidget* parent)
@@ -25,8 +22,13 @@ k9prefDVD::k9prefDVD(QWidget* parent)
 {
     Ui_prefDVD.setupUi(this);
     k9Config config;
+#ifdef BACKLITE
+    Ui_prefDVD.urOutput->setMode(KUrlRequester::DIRECTORY);
+    Ui_prefDVD.gbPerformances->hide();
+#else
     Ui_prefDVD.urOutput->setMode(KFile::Directory);
-    Ui_prefDVD.urOutput->setUrl(config.getPrefOutput());
+#endif
+    Ui_prefDVD.urOutput->setUrl(KUrl(config.getPrefOutput()));
     Ui_prefDVD.ckK3b->setChecked(config.getPrefK3b());
 
     Ui_prefDVD.ckAutoBurn->setChecked(config.getPrefAutoBurn());
@@ -58,7 +60,8 @@ k9prefDVD::k9prefDVD(QWidget* parent)
 }
 
 void k9prefDVD::loadLanguages(QComboBox *_combo) {
-  lng *arrLng=k9DVD::LangList();
+  lng arrLng[200];
+  k9DVD::LangList(arrLng);
   int index=0;
   _combo->clear();
   do {
