@@ -13,6 +13,7 @@
 #ifndef K9PREFMPEG4_H
 #define K9PREFMPEG4_H
 
+#include "k9common.h"
 #include "ui_prefMPEG4.h"
 #include "k9common.h"
 class k9prefMPEG4 : public QWidget
@@ -36,20 +37,23 @@ protected slots:
   virtual void ckMp4AspectRatioClick();
   virtual void rgVideoSizeChanged();
 
-  virtual void cbMp4CodecActivated( int ){};
-  virtual void cbMp4AudioCodecActivated( int ){};
+  virtual void cbMp4CodecActivated( int ){}
+  virtual void cbMp4AudioCodecActivated( int ){}
 
-  virtual void ck2passesClicked(){};
-  virtual void sbMp4SizeValueChanged( int ){};
-  virtual void sbAudioGainValueChanged( int ){};
+  virtual void ck2passesClicked(){}
+  virtual void sbMp4SizeValueChanged( int ){}
+  virtual void sbAudioGainValueChanged( int ){}
 
-  virtual void sbMp4NumberCDValueChanged( int ) {};
-  virtual void leMp4WidthTextChanged( const QString & ) {};
-  virtual void leMp4HeightTextChanged( const QString & ) {};
-  virtual void leMp4AudioBitrateTextChanged( const QString & ) {};
-  virtual void leMp4VideoBitrateTextChanged( const QString & ) {};
+  virtual void sbMp4NumberCDValueChanged( int ) {}
+  virtual void leMp4WidthTextChanged( const QString & ) {}
+  virtual void leMp4HeightTextChanged( const QString & ) {}
+  virtual void leMp4AudioBitrateTextChanged( const QString & ) {}
+  virtual void leMp4VideoBitrateTextChanged( const QString & ) {}
 
-  virtual void ckUseCacheClick() {};
+  virtual void ckUseCacheClick() {}
+  virtual void cbEncoderActivated( int);
+  virtual void bCropClicked() {}
+  virtual void sbValueChanged(int) {}
 
 private:
   Ui::prefMPEG4 Ui_prefMPEG4;
