@@ -27,17 +27,16 @@
 #include <qapplication.h>
 #include <qtoolbutton.h>
 #include <qlayout.h>
-
+#include <kdialog.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-
-#include <klocale.h>
+#ifndef BACKLITE
 #include <kiconloader.h>
+#endif
 #include "kviewmpeg2.h"
-#include "k9config.h"
 
 
 k9Widget::k9Widget(QWidget *parent):QWidget(parent) {
@@ -78,10 +77,10 @@ void k9Widget::paintEvent( QPaintEvent *) {
 
 kViewMPEG2::kViewMPEG2(QWidget *parent):QWidget(parent) {
     Ui_viewMPEG2.setupUi(this);
-    setWindowTitle(KDialog::makeStandardCaption(i18n("Title Preview"),this));
-    m_widget=NULL;
     Ui_viewMPEG2.bPlay->setIcon(SmallIcon("media-playback-start"));
     Ui_viewMPEG2.bStop->setIcon(SmallIcon("media-playback-stop"));
+    setWindowTitle(KDialog::makeStandardCaption(i18n("Title Preview"),this));
+    m_widget=NULL;
     connect(&m_player  , SIGNAL(setPosition(uint)), this, SLOT(setPosition(uint)));
     connect(&m_player  , SIGNAL(setMax(uint)), this, SLOT(setMax(uint)));
     connect(&m_player  , SIGNAL(setMin(uint)), this, SLOT(setMin(uint)));
