@@ -23,11 +23,13 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include "dvdread.h"
-#include <KTemporaryFile>
+#ifdef BACKLITE
+#else
 #include <KStandardDirs>
-#include <QApplication>
 #include <KMessageBox>
 #include <KLocale>
+#endif
+#include <QApplication>
 #include "k9dvdbackupinterface.h"
 #include <QTimer>
 
@@ -256,7 +258,6 @@ void k9play::insert_dummy_pack (int8_t *buf) {
 
 void k9play::run() {
     play();
-
 }
 
 
@@ -344,7 +345,7 @@ void k9play::play() {
     /* set read ahead cache usage */
     if (dvdnav_set_readahead_flag(dvdnav, DVD_READ_CACHE) != DVDNAV_STATUS_OK) {
         writeOutput( QString("ERR:Error on dvdnav_set_readahead_flag: %1\n").arg(dvdnav_err_to_string(dvdnav)));
-        emit sigError(i18n("Error on dvdnav_set_readahead_flag: %1",dvdnav_err_to_string(dvdnav)));
+        emit sigError(i18n("Error on dvdnav_set_readahead_flag: %1").arg(dvdnav_err_to_string(dvdnav)));
         return;
     }
 
@@ -353,7 +354,7 @@ void k9play::play() {
             dvdnav_audio_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
             dvdnav_spu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK) {
         writeOutput( QString("ERR:Error on setting languages: %1\n").arg(dvdnav_err_to_string(dvdnav)));
-        emit sigError(i18n("Error on setting languages: %1",dvdnav_err_to_string(dvdnav)));
+        emit sigError(i18n("Error on setting languages: %1").arg(dvdnav_err_to_string(dvdnav)));
         return ;
     }
 
@@ -361,7 +362,7 @@ void k9play::play() {
      * whole feature instead of just relatively to the current chapter */
     if (dvdnav_set_PGC_positioning_flag(dvdnav, 1) != DVDNAV_STATUS_OK) {
         writeOutput(QString("ERR:Error on dvdnav_set_PGC_positioning_flag: %1\n").arg(dvdnav_err_to_string(dvdnav)));
-        emit sigError(i18n("Error on dvdnav_set_PGC_positioning_flag: %1",dvdnav_err_to_string(dvdnav)));;
+        emit sigError(i18n("Error on dvdnav_set_PGC_positioning_flag: %1").arg(dvdnav_err_to_string(dvdnav)));;
         return ;
     }
 
@@ -383,7 +384,6 @@ void k9play::play() {
     while (!finished && !skipped && !m_aborted) {
         int result, event, len;
         uint8_t *buf = mem;
-//	qApp->processEvents();
         /* the main reading function */
 #if DVD_READ_CACHE
 
@@ -396,7 +396,7 @@ void k9play::play() {
 
         if (result == DVDNAV_STATUS_ERR) {
             writeOutput(QString("ERR:Error getting next block: %1\n").arg(dvdnav_err_to_string(dvdnav)));
-            emit sigError(i18n("Error getting next block: %1",dvdnav_err_to_string(dvdnav)));
+            emit sigError(i18n("Error getting next block: %1").arg(dvdnav_err_to_string(dvdnav)));
             return;
         }
         switch (event) {
@@ -540,10 +540,11 @@ void k9play::play() {
 #endif
 
     }
+    dvdnav_close(dvdnav);
     vamps.setNoData();
     vamps.wait();
     /* destroy dvdnav handle */
-    dvdnav_close(dvdnav);
+
 
     if (m_output) {
         if (! bcopy) {
