@@ -163,9 +163,10 @@ else
     m_dvdbackup=dvdbackup;
     reset();
     m_requant=NULL;
-    if (dvdbackup !=NULL)
+    if (dvdbackup !=NULL) {
     	m_bgUpdate = new k9bgUpdate(dvdbackup);
-    else
+        dvdbackup->setVamps(this);
+    } else
 	m_bgUpdate=NULL;
     rbuf_size= RBUF_SIZE;
     rbuf = new uchar[rbuf_size];
@@ -1130,6 +1131,11 @@ uint64_t k9vamps::getOutputBytes() {
     return bytes_written;
 }
 
+uint64_t k9vamps::getSkippedBytes() {
+    return skipped_aux_packs+skipped_video_packs;
+}
+
+
 void k9vamps::abort() {
     //fatal("vamps stopped");
     setNoData();
